# Changelog

## Version 0.0.5 (19-06-2025)

- Change to quackseq pulseprogramming framework.

## Version 0.0.4 (05-05-2024)

- Changed to FileManager class instead of QFileManager

## Version 0.0.3 (26-04-2024)

- Switched to new formbuilder provided by the nqrduck core

## Version 0.0.2 (18-04-2024)

- Automatic deployment to PyPI

## Version 0.0.1 (15-04-2024)

- Initial release
